@@ -1,6 +1,6 @@
 package Bundle::Everything;
 
-$VERSION = '0.04'
+$VERSION = '0.041'
 
 1;
 
@@ -55,18 +55,30 @@ Acme::Buffy
 
 Acme::Chef
 
+Acme::Enc
+
 Acme::Floral
 
+Acme::Homer
+
 Acme::Morse::Audible
 
+Acme::PIA::Export
+
 Acme::Playmate
 
 Acme::Pythonic
 
+Acme::Scripticide
+
+Acme::ScriptoPhrenic
+
 Acme::Tpyo
 
 Acme::Umlautify
 
+Acme::Void
+
 Acme::Wabby
 
 Alarm::Concurrent
@@ -75,6 +87,8 @@ Algorithm::BinPack
 
 Algorithm::Cluster
 
+Algorithm::CurveFit
+
 Algorithm::Diff
 
 Algorithm::Graphs::TransitiveClosure
@@ -133,6 +147,8 @@ Apache2::AuthenSmb
 
 Apache2::DBI
 
+Apache2::Filter::HTTPHeadersFixup
+
 Apache2::PageKit
 
 Apache::ACEProxy
@@ -173,6 +189,8 @@ Apache::AuthNISPlus
 
 Apache::AuthPerLDAP
 
+Apache::AuthTkt
+
 Apache::Authen::Program
 
 Apache::AuthenCache
@@ -369,6 +387,8 @@ Apache::Reload
 
 Apache::Request
 
+Apache::Request::I18N
+
 Apache::RequestNotes
 
 Apache::Roaming
@@ -435,6 +455,8 @@ Apache::TransLDAP
 
 Apache::Upload
 
+Apache::Upload::I18N
+
 Apache::UploadMeter
 
 Apache::UploadSvr
@@ -479,6 +501,8 @@ Archive::Ar
 
 Archive::Cabinet
 
+Archive::Chm
+
 Archive::Parity
 
 Archive::Tar
@@ -547,6 +571,8 @@ Attribute::Types
 
 Audio::CD
 
+Audio::Cuefile::Parser
+
 Audio::DB
 
 Audio::Ecasound
@@ -557,6 +583,8 @@ Audio::FLAC::Header
 
 Audio::File
 
+Audio::MPD
+
 Audio::MPEG
 
 Audio::MikMod
@@ -569,8 +597,12 @@ Audio::OSS
 
 Audio::Play::MPG321
 
+Audio::Radio::Sirius
+
 Audio::SoundFile
 
+Audio::TagLib
+
 AudioCD
 
 AudioCD::Mac
@@ -625,6 +657,8 @@ B::Size
 
 B::TerseSize
 
+BBCode::Parser
+
 BBDB
 
 BBDB::Export
@@ -665,8 +699,14 @@ Bio::Genex
 
 Bio::MAGE
 
+Bio::MCPrimers
+
+Bio::Phylo
+
 Bio::SAGE
 
+Bio::mGen
+
 Bit::Vector
 
 BizTalk
@@ -693,6 +733,8 @@ BnP
 
 Boulder
 
+BoxBackup
+
 Bryar::DataSource::SVNRepos
 
 Bundle::BDFOY
@@ -707,6 +749,8 @@ Bundle::KohaSupport
 
 Bundle::Perl6
 
+Bundle::Rose
+
 Bundle::SSH
 
 Bundle::Test
@@ -743,6 +787,8 @@ Business::OnlinePayment::Moneris
 
 Business::OnlinePayment::WorldPay::Junior
 
+Business::PayPal::SDK
+
 Business::Payroll
 
 Business::Payroll::AU::PAYG
@@ -771,6 +817,8 @@ CDDB
 
 CDDB::Fake
 
+CGI::Ajax
+
 CGI::Application
 
 CGI::Application::GDGraph::lines_ap
@@ -779,6 +827,10 @@ CGI::Application::PhotoGallery
 
 CGI::Application::Plugin::CompressGzip
 
+CGI::Application::Plugin::DevPopup
+
+CGI::Application::Plugin::Eparam
+
 CGI::Application::Plugin::HtmlTidy
 
 CGI::Application::Plugin::Stream
@@ -795,6 +847,10 @@ CGI::CList
 
 CGI::Cache
 
+CGI::Carp::DebugScreen
+
+CGI::ContactForm
+
 CGI::DBTables
 
 CGI::Debug
@@ -805,6 +861,8 @@ CGI::Echo
 
 CGI::Enurl
 
+CGI::Ex
+
 CGI::Explorer
 
 CGI::FormBuilder
@@ -813,6 +871,8 @@ CGI::FormFactory
 
 CGI::FormMagick
 
+CGI::FormManager
+
 CGI::Formalware
 
 CGI::Getopt
@@ -831,6 +891,8 @@ CGI::MultiValuedHash
 
 CGI::MxScreen
 
+CGI::NoPoison
+
 CGI::Out
 
 CGI::Panel
@@ -881,6 +943,8 @@ CGI::Validate
 
 CGI::WML
 
+CGI::WebApp
+
 CGI::XML
 
 CGI::XMLForm
@@ -891,10 +955,14 @@ CIPP
 
 CLucene
 
+CMS::Mediawiki
+
 CORBA::IDLtree
 
 CORBA::IOP::IOR
 
+CORBA::Python
+
 CORBA::XPIDL
 
 CPAN
@@ -929,6 +997,8 @@ Cartography::Projection::GCTP
 
 Catalog
 
+Catalyst::Plugin::Authorization::CDBI::GroupToken
+
 Cdk
 
 CfgTie
@@ -957,8 +1027,16 @@ Chart::XMGR
 
 Chatbot::Alpha
 
+Chatbot::Alpha::Sort
+
+Chatbot::Alpha::Syntax
+
+Chatbot::Alpha::Tutorial
+
 Chatbot::Eliza
 
+Chatbot::RiveScript
+
 Chemistry::Elements
 
 Chemistry::File::PDB
@@ -977,12 +1055,18 @@ Class::Accessor
 
 Class::ArrayObjects
 
+Class::AutoAccess
+
 Class::AutoloadCAN
 
 Class::BlackHole
 
 Class::Classless
 
+Class::Classless::DBI
+
+Class::Clone
+
 Class::Closure
 
 Class::Contract
@@ -1003,6 +1087,8 @@ Class::DBI::Plugin::DeepAbstractSearchPager
 
 Class::DBI::Plugin::Pager
 
+Class::DBI::Storable
+
 Class::DBI::Template
 
 Class::DBI::Test::TempDB
@@ -1019,6 +1105,8 @@ Class::Decorator
 
 Class::Delegate
 
+Class::Driver
+
 Class::EHierarchy
 
 Class::Eroot
@@ -1029,6 +1117,8 @@ Class::Fields
 
 Class::Flyweight
 
+Class::GAPI
+
 Class::Handler
 
 Class::Holon
@@ -1043,6 +1133,8 @@ Class::Loader
 
 Class::MakeMethods
 
+Class::Measure
+
 Class::MethodFilter
 
 Class::MethodMaker
@@ -1089,6 +1181,8 @@ Class::Translucent
 
 Class::Tree
 
+Class::Unique
+
 Class::WhiteHole
 
 Class::XPath
@@ -1097,6 +1191,10 @@ Clips
 
 Cmenu
 
+Cobalt::LCD
+
+Color::Scheme
+
 Commands::Guarded
 
 Compress::Bzip2
@@ -1129,6 +1227,8 @@ Config::Properties
 
 Config::Scoped
 
+Config::Sofu
+
 Config::YUM
 
 ConfigReader::Simple
@@ -1171,6 +1271,8 @@ Convert::GeekCode
 
 Convert::IBM390
 
+Convert::Lucene
+
 Convert::Morse
 
 Convert::PEM
@@ -1219,6 +1321,8 @@ Crypt::ECB
 
 Crypt::ElGamal
 
+Crypt::GCrypt
+
 Crypt::GOST
 
 Crypt::GPG
@@ -1279,6 +1383,8 @@ Crypt::SEAL2
 
 Crypt::SKey
 
+Crypt::SaltedHash
+
 Crypt::Schnorr::AuthSign
 
 Crypt::Shark
@@ -1321,6 +1427,10 @@ Cz::Speak
 
 DB2::db
 
+DB::Table
+
+DB::Table::Row
+
 DBA::Backup
 
 DBA::Backup::mysql
@@ -1443,6 +1553,8 @@ DBIx::Hash2Table
 
 DBIx::Informix::Perform
 
+DBIx::Interpolate
+
 DBIx::Lookup::Field
 
 DBIx::MSSQLReporter
@@ -1455,6 +1567,8 @@ DBIx::Password
 
 DBIx::Recordset
 
+DBIx::Roles
+
 DBIx::SQLEngine
 
 DBIx::SchemaView
@@ -1477,8 +1591,14 @@ DBIx::TableReferences::MSSQL
 
 DBIx::TextIndex
 
+DBIx::Transaction
+
 DBIx::Tree
 
+DBIx::VersionedSchema
+
+DBIx::Wrapper::Config
+
 DBIx::XHTML_Table
 
 DBIx::XML::DataLoader
@@ -1513,6 +1633,8 @@ DCE::Status
 
 DCE::UUID
 
+DCOP::Amarok::Player
+
 DDL::Oracle
 
 DES
@@ -1535,8 +1657,6 @@ Danga::Socket
 
 Data::All
 
-Data::BinStruct
-
 Data::Binder
 
 Data::BitMask
@@ -1553,6 +1673,8 @@ Data::Describe
 
 Data::Diff
 
+Data::Dumper::HTML
+
 Data::Favorites
 
 Data::Flow
@@ -1599,6 +1721,8 @@ Data::Sofu
 
 Data::Stash
 
+Data::Sync
+
 Data::Tabular
 
 Data::Tabular::Dumper
@@ -1637,6 +1761,8 @@ Date::Handler
 
 Date::Holidays::AU
 
+Date::Holidays::PT
+
 Date::ICal
 
 Date::ISO
@@ -1653,6 +1779,8 @@ Date::Parse
 
 Date::Roman
 
+Date::Say::Czech
+
 Date::Simple
 
 Date::Simple::Month
@@ -1747,6 +1875,8 @@ Devel::Modlist
 
 Devel::Peek
 
+Devel::PerlySense
+
 Devel::RegExp
 
 Devel::SearchINC
@@ -1765,6 +1895,8 @@ Devel::TraceLoad
 
 Devel::TraceMethods
 
+Devel::Trampoline
+
 Devel::Truth_Table
 
 Device::ISDN::OCLM
@@ -1773,6 +1905,8 @@ Device::ParallelPort
 
 Device::SerialPort
 
+Device::SerialPort::Xmodem
+
 Device::WxM2
 
 Dialog
@@ -1809,8 +1943,14 @@ Digest::Whirlpool
 
 Dir::Purge
 
+Drupal::Module::Starter
+
+EB
+
 ERG
 
+ETL::Pequel
+
 Ekahau
 
 ElectricArc
@@ -1831,6 +1971,12 @@ Embedix::ECD
 
 Encode::Arabic
 
+Encode::Detect
+
+Encode::Detect::Detector
+
+Encode::EUCJPMS
+
 Encode::HEBCI
 
 Encode::HanConvert
@@ -1899,6 +2045,8 @@ ExtUtils::DynaGlue
 
 ExtUtils::F77
 
+ExtUtils::ModuleMaker
+
 ExtUtils::ParseXS
 
 ExtUtils::configPL
@@ -1923,6 +2071,8 @@ Festival::Client
 
 Festival::Client::Async
 
+File::Atomic
+
 File::BSDGlob
 
 File::Backup
@@ -1987,6 +2137,8 @@ File::Searcher::Similars
 
 File::Signature
 
+File::Size
+
 File::Slurp
 
 File::Sort
@@ -2005,6 +2157,8 @@ File::Tabular
 
 File::Tail
 
+File::Tail::App
+
 File::Temp
 
 File::Touch
@@ -2021,6 +2175,8 @@ File::lockf
 
 File::sudoers
 
+FileSys::Tree
+
 Filesys::Df
 
 Filesys::DiskFree
@@ -2045,6 +2201,8 @@ Filesys::mntent
 
 Filesys::statfs
 
+Filter::CommaEquals
+
 Filter::Crypto
 
 Filter::NumberLines
@@ -2123,6 +2281,8 @@ Fortran::NameList
 
 FrameMaker::MifTree
 
+FrameNet::WordNet::Detour
+
 FreezeThaw
 
 Frontier::RPC
@@ -2165,10 +2325,14 @@ GISI::SHAPE
 
 GMail::Checker
 
+GMail::IMAPD
+
 GSM::SMS
 
 GSS
 
+GStreamer
+
 GTop
 
 Games::AIBots
@@ -2177,6 +2341,8 @@ Games::Alak
 
 Games::AlphaBeta
 
+Games::Baseball::Scorecard
+
 Games::Bingo
 
 Games::Cards
@@ -2187,8 +2353,12 @@ Games::Crosswords
 
 Games::Dice
 
+Games::Dice::Probability
+
 Games::Dissociate
 
+Games::DungeonMaker
+
 Games::Go::AGATourn
 
 Games::Go::GoPair
@@ -2199,10 +2369,14 @@ Games::Multiplayer::Manager
 
 Games::Object
 
+Games::SGF::Tournament
+
 Games::Score
 
 Games::Sequential
 
+Games::Sudoku::General
+
 Games::Tournament::BlackJack
 
 Games::Traveller::UWP
@@ -2217,10 +2391,14 @@ Gemstone
 
 Genezzo
 
+Geo::Caching
+
 Geo::Coordinates::Convert
 
 Geo::Coordinates::OSGB
 
+Geo::Coordinates::Parser
+
 Geo::Coordinates::UTM
 
 Geo::CountryFlags
@@ -2265,6 +2443,8 @@ Getopt::Gnu
 
 Getopt::Help
 
+Getopt::Long::Descriptive
+
 Getopt::Long::File
 
 Getopt::Mixed
@@ -2291,6 +2471,8 @@ GnuPG
 
 GnuPG::Interface
 
+Goo
+
 Graph
 
 Graph::Kruskal
@@ -2335,6 +2517,8 @@ Gtk2::Ex::PopupWindow
 
 Gtk2::MozEmbed
 
+Gtk2::SourceView
+
 Gtk2::TrayManager
 
 Gtk::Dialog
@@ -2351,6 +2535,8 @@ HPUX::SDUX
 
 HTML::ActiveLink
 
+HTML::BBReverse
+
 HTML::BarChart
 
 HTML::BarGraph
@@ -2367,6 +2553,10 @@ HTML::CalendarMonthDB
 
 HTML::Chunks
 
+HTML::Chunks::Local
+
+HTML::Chunks::Super
+
 HTML::Debug
 
 HTML::Demoroniser
@@ -2437,6 +2627,8 @@ HTML::ParseBrowser
 
 HTML::Parser
 
+HTML::PopupTreeSelect::Dynamic
+
 HTML::Processor
 
 HTML::Simple
@@ -2461,10 +2653,14 @@ HTML::TableLayout
 
 HTML::Tabulate
 
+HTML::TagUtil
+
 HTML::Tagset
 
 HTML::Template
 
+HTML::Template::Compiled
+
 HTML::Template::Set
 
 HTML::TokeParser
@@ -2483,6 +2679,8 @@ HTTP::BrowserDetect
 
 HTTP::Cache::Transparent
 
+HTTP::Client
+
 HTTP::Cookies
 
 HTTP::Cookies::Find
@@ -2495,6 +2693,8 @@ HTTP::Cookies::Safari
 
 HTTP::Cookies::iCab
 
+HTTP::CryptoCookie
+
 HTTP::DAV
 
 HTTP::DAVServer
@@ -2579,6 +2779,8 @@ Heap::Simple::Perl
 
 Heap::Simple::XS
 
+Hey::heyPass
+
 Hints
 
 Hook::PrePostCall
@@ -2597,28 +2799,42 @@ IBM::LoadLeveler
 
 IMAP::Admin
 
+IMAP::Client
+
 IO::AtomicFile
 
 IO::Default
 
+IO::Dir::Recursive
+
 IO::Event
 
 IO::File::Lockable
 
 IO::Filter
 
+IO::LCDproc
+
 IO::Lines
 
 IO::Multiplex
 
+IO::NestedCapture
+
 IO::React
 
+IO::Redirect
+
 IO::Scalar
 
 IO::ScalarArray
 
 IO::Select
 
+IO::Socket::PortState
+
+IO::Socket::PortState::cPanel
+
 IO::String
 
 IO::Stringy
@@ -2637,6 +2853,8 @@ IO::WrapTie
 
 IO::Zlib
 
+IP::Anonymous
+
 IPC::Cache
 
 IPC::ChildSafe
@@ -2753,8 +2971,20 @@ Interface::Param
 
 Ioctl
 
+Iterator
+
+Iterator::DBI
+
+Iterator::IO
+
+Iterator::Misc
+
+Iterator::Util
+
 JUNOS
 
+Jabber::PubSub::JEAI
+
 Java
 
 Java::Build
@@ -2765,10 +2995,14 @@ Java::Swing
 
 JavaScript
 
+JavaScript::Squish
+
 Kwiki
 
 LEGO::RCX
 
+LSF::Hosts
+
 LWP
 
 LWP::Conn
@@ -2793,6 +3027,8 @@ LWPx::ParanoidAgent
 
 Language::Basic
 
+Language::Befunge
+
 Language::DATR::DATR2XML
 
 Language::Frink::Eval
@@ -2813,24 +3049,34 @@ Language::XSB
 
 Language::Zcode
 
+Lemonldap::Cluster::Status
+
 Lemonldap::Config::Parameters
 
 Lemonldap::Crypto
 
-Lemonldap::Handler
-
 Lemonldap::Handlers::Generic
 
+Lemonldap::NG::Handler
+
+Lemonldap::NG::Portal
+
 Lemonldap::Portal
 
 Lemonldap::Portal::Authntsso
 
 Lemonldap::Portal::Cda
 
+Lemonldap::Portal::Session
+
 Lemonldap::Portal::Sslsso
 
 Lemonldap::Portal::Standard
 
+Lemonolap
+
+Lemonolap::Log4lemon
+
 Lexical::Typeglob
 
 Lingua::AlignmentSet
@@ -2839,6 +3085,8 @@ Lingua::Alphabet::Phonetic
 
 Lingua::Conjunction
 
+Lingua::DE::Wortschatz
+
 Lingua::DetectCharset
 
 Lingua::EN::AddressParse
@@ -2881,8 +3129,6 @@ Lingua::GA::Gramadoir
 
 Lingua::GL::Stemmer
 
-Lingua::Han2PinYin
-
 Lingua::Ident
 
 Lingua::Identify
@@ -2931,6 +3177,8 @@ Lingua::Stem::Snowball::Da
 
 Lingua::TH::Segmentation
 
+Lingua::TR::Hyphenate
+
 Lingua::Tolkien::BURL
 
 Lingua::Treebank
@@ -2971,6 +3219,8 @@ Linux::Cpuinfo
 
 Linux::Fuser
 
+Linux::Inotify
+
 Linux::LVM
 
 Linux::MemInfo
@@ -2979,10 +3229,14 @@ Linux::Pid
 
 Linux::Svgalib
 
+List::Compare
+
 List::Comprehensions
 
 List::Intersperse
 
+List::MRU
+
 List::Part
 
 List::Rotation::Cycle
@@ -3053,12 +3307,16 @@ Log::Dispatch::ToTk
 
 Log::Dispatch::Win32EventLog
 
+Log::Localized
+
 Log::Log4perl
 
 Log::Topics
 
 Log::TraceMessages
 
+Log::WithCallbacks
+
 Logfile
 
 Lyrics::Fetcher::Google
@@ -3073,6 +3331,8 @@ MARC::XML
 
 MIDI
 
+MIDI::Praxis::Variation
+
 MIME::Base64
 
 MIME::Decoder
@@ -3203,6 +3463,8 @@ Mac::Sound
 
 Mac::Speech
 
+Mac::Spotlight
+
 Mac::SysProfile
 
 Mac::Types
@@ -3299,6 +3561,8 @@ Mail::VersionTracker
 
 Mail::Vmailmgr
 
+Mail::vpopmaild
+
 Make
 
 Mariachi
@@ -3353,6 +3617,8 @@ Math::Calc::Units
 
 Math::Cephes
 
+Math::ConvexHull
+
 Math::Derivative
 
 Math::ErrorPropagation
@@ -3417,6 +3683,8 @@ Math::MatrixReal::Ext1
 
 Math::Nocarry
 
+Math::Orthonormalize
+
 Math::Pari
 
 Math::Polygon
@@ -3445,8 +3713,6 @@ Math::Random::MT
 
 Math::Random::MT::Auto
 
-Math::Random::MT::Net
-
 Math::Random::TT800
 
 Math::Round
@@ -3459,8 +3725,18 @@ Math::Spline
 
 Math::Symbolic
 
+Math::Symbolic::Custom::CCompiler
+
+Math::Symbolic::Custom::Pattern
+
+Math::SymbolicX::Inline
+
+Math::Taylor
+
 Math::Telephony::ErlangB
 
+Math::Telephony::ErlangC
+
 Math::Trig
 
 Math::VecStat
@@ -3487,6 +3763,12 @@ Mobile::UserAgent
 
 Mobile::WURFL
 
+Mobile::Wurfl
+
+ModPerl::PackageRegistry
+
+Model3D::WavefrontObject
+
 Modem::Vgetty
 
 Module::Build
@@ -3499,6 +3781,8 @@ Module::MakeDist
 
 Module::MakefilePL::Parse
 
+Module::Optional
+
 Module::Reload
 
 Module::ScanDeps
@@ -3509,6 +3793,16 @@ Mon::Client
 
 Mon::SNMP
 
+MonetDB::CLI
+
+MonetDB::CLI::MapiLib
+
+MonetDB::CLI::MapiPP
+
+MonetDB::CLI::MapiXS
+
+Mono
+
 Mozilla::Backup
 
 Msql
@@ -3559,6 +3853,8 @@ Net::CyanChat
 
 Net::CyanChat::Server
 
+Net::DBus
+
 Net::DHCP
 
 Net::DHCP::Watch
@@ -3577,6 +3873,8 @@ Net::DNS::SEC
 
 Net::DNS::TestNS
 
+Net::DNS::ValueDomain::DDNS
+
 Net::DNS::Zone::Parser
 
 Net::DRI
@@ -3623,6 +3921,8 @@ Net::ICB
 
 Net::ICQ
 
+Net::ICQ::On
+
 Net::ICQV5
 
 Net::ICQV5CD
@@ -3657,6 +3957,8 @@ Net::LMTP
 
 Net::LPR
 
+Net::LibLO
+
 Net::Mac::Vendor
 
 Net::Milter
@@ -3703,6 +4005,8 @@ Net::Printer
 
 Net::QMQP
 
+Net::RGTP
+
 Net::RTSP
 
 Net::RULI
@@ -3729,6 +4033,8 @@ Net::SMS::Web
 
 Net::SMTP
 
+Net::SMTP::IPMM
+
 Net::SNMP
 
 Net::SNMP::Interfaces
@@ -3757,6 +4063,8 @@ Net::Telnet
 
 Net::Telnet::Cisco
 
+Net::Telnet::Cisco::IOS
+
 Net::Time
 
 Net::Traceroute
@@ -3765,6 +4073,8 @@ Net::Traceroute6
 
 Net::UDP
 
+Net::USPS
+
 Net::Vypress::Chat
 
 Net::WWD
@@ -3779,6 +4089,8 @@ Net::XWhois
 
 Net::Z3950
 
+Net::eBay
+
 Net::hostent
 
 Net::iTMS
@@ -3925,6 +4237,8 @@ OLE::Storage_Lite
 
 OODoc
 
+ORM
+
 OS2::ExtAttr
 
 OS2::FTP
@@ -3939,14 +4253,20 @@ Oak
 
 ObjStore
 
+Object::AutoAccessor
+
 Object::Info
 
+Object::InsideOut
+
 Object::Mediator
 
 Object::POOF
 
 Object::Realize::Later
 
+Object::Trampoline
+
 Object::Transaction
 
 Ogg::Vorbis::Header
@@ -3957,6 +4277,8 @@ OpenGL
 
 OpenOffice::OODoc
 
+OpenOffice::PerlPoint
+
 Openview::Message
 
 Orac
@@ -4015,12 +4337,16 @@ PDF::PlainLayout
 
 PDF::Report
 
+PDF::Report::Table
+
 PDF::ReportWriter
 
 PDF::Reuse
 
 PDF::Reuse::Tutorial
 
+PDF::Table
+
 PDF::Template
 
 PDL
@@ -4029,6 +4355,8 @@ PDL::IO::HDF5
 
 PDL::LAPACK
 
+PDL::LinearAlgebra
+
 PDL::Meschach
 
 PDL::NetCDF
@@ -4047,14 +4375,20 @@ PGP::Sign
 
 PGPLOT
 
+PGPLOT::Simple
+
 PHP
 
 PHP::Include
 
+PHP::Interpreter
+
 PHP::MySQL_Session
 
 PHP::Session
 
+PHP::Session::DB
+
 POE::API::Hooks
 
 POE::API::Peek
@@ -4081,6 +4415,8 @@ POE::Component::Enc::Flac
 
 POE::Component::Enc::Ogg
 
+POE::Component::Growl
+
 POE::Component::IRC
 
 POE::Component::IRC::Onjoin
@@ -4119,6 +4455,8 @@ POE::Session::Cascading
 
 POE::Session::GladeXML
 
+POSIX::SchedYield
+
 PPM
 
 PPM::Make
@@ -4147,6 +4485,8 @@ Parse::Lex
 
 Parse::Lexer
 
+Parse::MediaWikiDump
+
 Parse::Nessus::ENX
 
 Parse::Nessus::NBE
@@ -4179,6 +4519,8 @@ Perl
 
 Perl6::Classes
 
+Perl6::Doc
+
 Perl6::Interpolators
 
 Perl6::Parameters
@@ -4193,6 +4535,8 @@ PerlIO::gzip
 
 PerlIO::locale
 
+PerlIO::via::CBC
+
 PerlMenu
 
 PerlPoint::Package
@@ -4241,6 +4585,8 @@ Pod::HTML2Pod
 
 Pod::Hlp
 
+Pod::Index
+
 Pod::LaTeX
 
 Pod::Lyx
@@ -4255,6 +4601,8 @@ Pod::Parser
 
 Pod::Pdf
 
+Pod::PerlPoint
+
 Pod::Readme
 
 Pod::Rtf
@@ -4309,6 +4657,8 @@ PostScript::PseudoISO
 
 PostScript::Resources
 
+PostScript::Simple::Table
+
 PostScript::StandardEncoding
 
 PostScript::TextBlock
@@ -4327,6 +4677,8 @@ Proc::Fork
 
 Proc::Forkfunc
 
+Proc::PID::File::Fcntl
+
 Proc::ParallelLoop
 
 Proc::ProcessTable
@@ -4409,6 +4761,8 @@ RFID::Base
 
 RFID::EPC
 
+RFID::ISO15693::Tag
+
 RFID::Matrics
 
 RPC::ONC
@@ -4437,6 +4791,12 @@ RTF::Tokenizer
 
 RTSP::Lite
 
+RTx::RightsMatrix
+
+RTx::Shredder
+
+Ratpoison
+
 Rcs
 
 Readonly
@@ -4479,10 +4839,26 @@ Resources
 
 Roman
 
+Rose
+
+Rose::DB::Object
+
+Rose::DateTime
+
+Rose::HTML::Objects
+
+Rose::Object
+
+Rose::URI
+
+Rosetta
+
 Router::LG
 
 SAP::Rfc
 
+SCGI
+
 SCUBA::Table::NoDeco
 
 SGI::FAM
@@ -4505,6 +4881,8 @@ SICStus
 
 SIL::Shoe
 
+SLOOPS
+
 SMIMEUtil
 
 SNMP
@@ -4519,6 +4897,8 @@ SNMP::Util
 
 SOAP::Clean
 
+SOAP::Data::ComplexType
+
 SOAP::WSDL
 
 SOOP
@@ -4531,6 +4911,10 @@ SQL::Builder
 
 SQL::Generator
 
+SQL::Interpolate
+
+SQL::QueryBroker
+
 SQL::Routine
 
 SQL::Schema
@@ -4557,6 +4941,8 @@ SVG::Template::Graph
 
 SVG::XML
 
+SVN::Look
+
 SWIFT::Factory::ApplicationHeader
 
 SWIFT::Factory::BasicHeader
@@ -4669,6 +5055,8 @@ Slash
 
 Slash::OurNet
 
+Slauth
+
 Smirch
 
 Socket6
@@ -4691,6 +5079,8 @@ Solaris::InstallDB
 
 Solaris::Kstat
 
+Solaris::Lgrp
+
 Solaris::MapDev
 
 Solaris::Package
@@ -4737,6 +5127,8 @@ Sprite
 
 Stat::lsMode
 
+Statistics::CalinskiHarabasz
+
 Statistics::ChiSquare
 
 Statistics::ConwayLife
@@ -4745,6 +5137,10 @@ Statistics::Descriptive
 
 Statistics::Distributions
 
+Statistics::Gap
+
+Statistics::Hartigan
+
 Statistics::LTU
 
 Statistics::MaxEntropy
@@ -4789,6 +5185,8 @@ String::ShellQuote
 
 String::Strip
 
+String::Util
+
 Sub::Assert
 
 Sub::Curry
@@ -4801,6 +5199,8 @@ Sub::Recursive
 
 Sub::Regex
 
+Sub::Timebound
+
 Sun::Solaris::Exacct
 
 Sun::Solaris::Privilege
@@ -4829,6 +5229,8 @@ Symbol::Approx::Sub
 
 Symbol::Table
 
+Symbol::Values
+
 Synergy
 
 Syntax::Highlight::HTML
@@ -4851,6 +5253,8 @@ Sys::Filesystem::Solaris
 
 Sys::Filesystem::Unix
 
+Sys::Gamin
+
 Sys::Hostname::Long
 
 Sys::Lastlog
@@ -4899,16 +5303,18 @@ Teamspeak
 
 Telephony::CountryDialingCodes
 
-Telephony::Phonedev
-
 Template
 
+Template::Plugin::ASCIITable
+
 Template::Plugin::Config::General
 
 Template::Plugin::Data::HTMLDumper
 
 Template::Plugin::HTML::BBCode
 
+Template::Plugin::Lingua::EN::Inflect
+
 Template::Plugin::SSI
 
 Template::Plugin::StickyQuery
@@ -4917,6 +5323,8 @@ Template::Plugin::Translit::RU
 
 Template::TagParser
 
+Teradata::BTET
+
 Term::ANSIScreen
 
 Term::Activity
@@ -4975,6 +5383,8 @@ Test::File
 
 Test::File::Find::Rule
 
+Test::Files
+
 Test::Fixme
 
 Test::ISBN
@@ -5001,16 +5411,22 @@ Test::Number::Delta
 
 Test::Numeric
 
+Test::PerlTidy
+
 Test::Pod
 
 Test::Portability::Files
 
+Test::RandomResults
+
 Test::Reporter
 
 Test::Signature
 
 Test::Simple
 
+Test::Spelling
+
 Test::TempDatabase
 
 Test::URI
@@ -5051,6 +5467,8 @@ Text::Convert::ToImage
 
 Text::DelimMatch
 
+Text::Diff3
+
 Text::DoubleMetaphone
 
 Text::Embed
@@ -5097,12 +5515,18 @@ Text::Orientation
 
 Text::Parser
 
+Text::Printf
+
 Text::Query
 
+Text::Record::Deduper
+
 Text::Refer
 
 Text::Scan
 
+Text::Scraper
+
 Text::ScriptTemplate
 
 Text::Shift
@@ -5129,6 +5553,10 @@ Text::Templar
 
 Text::Template
 
+Text::Templet
+
+Text::Textile
+
 Text::Tokenizer
 
 Text::TreeFile
@@ -5151,6 +5579,8 @@ Text::xSV
 
 Thesaurus
 
+Thread::Barrier
+
 Thread::Group
 
 Thread::Pool
@@ -5165,6 +5595,8 @@ Tie::AliasHash
 
 Tie::Array::CustomStorage
 
+Tie::Array::Huge
+
 Tie::Assert
 
 Tie::CPHash
@@ -5219,6 +5651,8 @@ Tie::HashDefaults
 
 Tie::IxHash
 
+Tie::Judy
+
 Tie::LDAP
 
 Tie::LLHash
@@ -5237,6 +5671,8 @@ Tie::PerfectHash
 
 Tie::Persistent
 
+Tie::Plural::Scalar
+
 Tie::RDBM
 
 Tie::RangeHash
@@ -5283,6 +5719,8 @@ Time::DaysInMonth
 
 Time::Duration::sv
 
+Time::Elapse
+
 Time::Format
 
 Time::HiRes
@@ -5291,6 +5729,8 @@ Time::JulianDateTime
 
 Time::JulianDay
 
+Time::Normalize
+
 Time::Object
 
 Time::ParseDate
@@ -5383,6 +5823,8 @@ Tk::FontDialog
 
 Tk::Getopt
 
+Tk::Gpack
+
 Tk::Graph
 
 Tk::GraphViz
@@ -5429,8 +5871,6 @@ Tk::ObjScanner
 
 Tk::Olwm
 
-Tk::OutlookBar
-
 Tk::PNG
 
 Tk::Pane
@@ -5471,6 +5911,8 @@ Tk::TFrame
 
 Tk::TIFF
 
+Tk::TOTD
+
 Tk::TabFrame
 
 Tk::TabbedForm
@@ -5505,6 +5947,8 @@ Tk::autobind
 
 ToolTalk
 
+Tree
+
 Tree::DAG_Node
 
 Tree::Fat
@@ -5515,6 +5959,8 @@ Tree::Menu
 
 Tree::Nary
 
+Tree::Node
+
 Tree::Ternary
 
 Tree::Ternary_XS
@@ -5567,6 +6013,8 @@ Unix::ConfigFile
 
 Unix::Login
 
+Unix::PID
+
 Unix::Processors
 
 Unix::Syslog
@@ -5615,6 +6063,8 @@ VMS::System
 
 VMS::User
 
+VMS::smg
+
 VRML
 
 VRML::Base
@@ -5629,6 +6079,8 @@ Variable::Alias
 
 Verilog::CodeGen
 
+Verilog::GetInfo
+
 Verilog::Language
 
 Verilog::Parser
@@ -5661,12 +6113,20 @@ WWW::BBSWatch
 
 WWW::Blog::Identify
 
+WWW::Bookmarks
+
 WWW::Cache::Google
 
 WWW::Dilbert
 
 WWW::Extractor
 
+WWW::Google::PageRank
+
+WWW::Google::SiteMap
+
+WWW::Google::Video
+
 WWW::ImageSpool
 
 WWW::Lunarstorm
@@ -5677,6 +6137,8 @@ WWW::Mail::Hotmail
 
 WWW::Mechanize
 
+WWW::NanoRef
+
 WWW::Patent::Page
 
 WWW::Pipeline
@@ -5695,10 +6157,14 @@ WWW::Search
 
 WWW::Search::AlltheWeb
 
+WWW::Search::Bookmarks
+
 WWW::Search::Ebay
 
 WWW::Search::Excite
 
+WWW::Search::Feedster
+
 WWW::Search::FirstGov
 
 WWW::Search::Go
@@ -5707,26 +6173,44 @@ WWW::Search::Google
 
 WWW::Search::HotBot
 
+WWW::Search::ISBNDB
+
 WWW::Search::Lycos
 
 WWW::Search::Magellan
 
 WWW::Search::RpmFind
 
+WWW::Search::UrbanDictionary
+
 WWW::Search::Yahoo
 
 WWW::SherlockSearch
 
 WWW::ShopBot
 
+WWW::Shorten::KUSO
+
 WWW::Statistics
 
+WWW::Sucksub::Attila
+
+WWW::Sucksub::Divxstation
+
+WWW::Sucksub::Frigo
+
+WWW::Sucksub::Vostfree
+
+WWW::TVguide::NL
+
 WWW::URLToys
 
 WWW::Webjay
 
 WWW::Yahoo::DrivingDirections
 
+WWW::Yandex::TIC
+
 Wais
 
 Watchdog::HTTPService
@@ -5763,6 +6247,8 @@ Wiki::Gateway
 
 Wily
 
+Win32::AD::Control::DirSync
+
 Win32::ADO
 
 Win32::API
@@ -5807,6 +6293,8 @@ Win32::FileOp
 
 Win32::FileType
 
+Win32::Filenames
+
 Win32::GD
 
 Win32::GUI
@@ -5821,6 +6309,8 @@ Win32::GuiTest
 
 Win32::Guidgen
 
+Win32::IIS::Admin
+
 Win32::IIS:SMTP
 
 Win32::IPC
@@ -5875,12 +6365,18 @@ Win32::SerialPort
 
 Win32::SharedFileOpen
 
+Win32::ShellExt
+
 Win32::Shortcut
 
 Win32::Sound
 
 Win32::SoundRec
 
+Win32::SqlServer
+
+Win32::StreamNames
+
 Win32::SystemInfo
 
 Win32::UTCFileTime
@@ -6039,10 +6535,14 @@ XML::RDB
 
 XML::RSS
 
+XML::RSS::FOXSports
+
 XML::RegExp
 
 XML::Registry
 
+XML::SAX::ExpatXS
+
 XML::SAXDriver::CSV
 
 XML::SAXDriver::Excel
@@ -6053,6 +6553,8 @@ XML::Sablotron
 
 XML::Simple
 
+XML::Spew
+
 XML::Stream
 
 XML::Tidy
@@ -6063,6 +6565,8 @@ XML::Twig
 
 XML::UM
 
+XML::Validator::RelaxNG
+
 XML::Validator::Schema
 
 XML::Writer
@@ -6077,8 +6581,6 @@ XML::XQL
 
 XML::XSLT
 
-XML::Xalan
-
 XML::Xerces
 
 XML::miniXQL
@@ -6087,6 +6589,8 @@ XMLI
 
 Xbase
 
+Xfce4
+
 Xmms
 
 Xmms::Config
